![install_and_test](../../workflows/install_and_test/badge.svg)
![check_formatting](../../workflows/check_formatting/badge.svg)

# Pansat

**Accessing satellite and reanalysis data made easy.**


**pansat** provides a unified interface for a wide range of satellite, reanalysis and other meteorological data with a focus on data that is relevant for atmospheric research. Many of these datasets appear in different formats and are difficult to download and access in a consistent way. Therefore,  **pansat** tries to overcome this difficulties and provides user-friendly download functionalities that can be used within python or from the command line. Currently, **pansat** supports various gridded and ungridded datasets from different data providers and allows for a quick implementation of new data products. The user can specify time ranges, regions and variables for the datasets to be downloaded. This facilitates the access the data needed for case studies, climatological time series or collocations of different datasets. 

## Installation 


*pip install pansat* 



## Documentation

Online documentation and Examples for Pansat are available [here](https://pansat.readthedocs.io/en/latest/).


## Hurricane Laura (2020) as seen by GOES 


With **pansat** you can, for example, quickly find images for specific storm cases.


![Hurricane Laura (2020) as seen by GOES](/docs/index.png)

